@@ -2,6 +2,10 @@
 
 import click
 import logging
+import time
+
+logging.basicConfig(level=logging.ERROR)
+from colorama import Fore, Back, Style
 
 from . import server
 
@@ -18,6 +22,14 @@ from . import server
 )
 def main(domains: str) -> None:
 
+    logging.info('server started')
+
+    
+    print()
+    time.sleep(0.2)
+    print(Fore.BLUE + Style.BRIGHT + "Headwaters:" + Style.NORMAL+ " Simple Stream Sources" + Style.RESET_ALL)
+    time.sleep(0.3)
+    print()
     server.run(domains)
 
 if __name__ == "__main__":
