@@ -1,10 +1,26 @@
-from flask import Flask, jsonify, request, send_file
+from flask import Flask, jsonify, request, send_file, Response
 from flask_socketio import SocketIO
 
 import random
 import logging
+import pkgutil
+import threading
+import click
+
+from colorama import Fore, Back, Style
 
 logging.basicConfig(level=logging.INFO)
+flask_log = logging.getLogger('werkzeug')
+flask_log.setLevel(logging.ERROR)
+
+def secho(text, file=None, nl=None, err=None, color=None, **styles):
+    pass
+
+def echo(text, file=None, nl=None, err=None, color=None, **styles):
+    pass
+
+click.echo = echo
+click.secho = secho
 
 
 from ..engine import Engine
@@ -84,17 +100,25 @@ def add_word():
 @app.route('/ui', defaults={'path': ''})
 @app.route('/<path:path>')
 def catch_all(path):
-    print(path)
     if path.endswith('.js'):
-        return send_file(f"src/headwaters/{path}", mimetype="text/javascript")
+        r = pkgutil.get_data("headwaters", f"{path}")
+        return Response(r, mimetype="text/javascript")
+
     elif path.endswith('.css'):
-        return send_file(f"src/headwaters/{path}", mimetype="text/css")
+        r = pkgutil.get_data("headwaters", f"{path}")
+        return Response(r, mimetype="text/css")
+
     elif path.endswith('.ico'):
-        return send_file(f"src/headwaters/{path}")
+        r = pkgutil.get_data("headwaters", f"{path}")
+        return Response(r, mimetype="text/application")
+
     elif path.endswith('.svg'):
-        return send_file(f"src/headwaters/{path}")
+        r = pkgutil.get_data("headwaters", f"{path}")
+        return Response(r, mimetype="image/svg+xml")
+
     else:
-        return send_file("src/headwaters/ui/index.html", mimetype="text/html")
+        r = pkgutil.get_data("headwaters.ui", "index.html")
+        return Response(r, mimetype="text/html")
 
 @sio.event("connect")
 def connect_hndlr():
@@ -108,25 +132,33 @@ domains = []
 def run(selected_domains):
     """
 
-    what about: the Engine instances are created, then the generate method of each is multithreaded...
-    could the thread have access to the object properties in that thread? NO surely not
-    THIS SEEMS TO WORK?!?!?
-
-    ALSO CAN I KNOW INSTNATIATE ENGINE OBKECT OUTWITH SERVER
-    CAN I TEST THEM WITHOUT USING HTTP REQUESTS??
-
-    now the thinking is to have the domain classed available in the server scope
-    that way i can access the new_event() method of a domain instance fromt he generator thread and
-    also access it for CUD ops
-
     """
-
+    
     for selected_domain in selected_domains:
         domain = Domain(selected_domain)
         domains.append(domain)
         engines.append(Engine(domain, sio))
 
+    engine_threads = []
     for engine in engines:
-        sio.start_background_task(target=engine.generate)
+        # sio.start_background_task(target=engine.generate)
+        engine_threads.append(threading.Thread(target=engine.generate))
 
-    sio.run(app, debug=False)
+    for engine_thread in engine_threads:
+        engine_thread.start()
+
+    port = 5555 # set up a config file
+
+    print(Fore.GREEN + Style.BRIGHT + f"STREAMS: http://127.0.0.1:{port}"  + Style.RESET_ALL)
+    print(Fore.CYAN + Style.BRIGHT + f"UI: http://127.0.0.1:{port}/ui" + Style.RESET_ALL)
+    print()
+    print(Fore.RED + Style.DIM + "(CTRL-C to stop)" + Style.RESET_ALL)
+
+    sio.run(app, debug=False, port=port)
+
+    print()
+    print(f"Server stopping...")
+    print()
+
+    for engine in engines:
+        engine.stop()
\ No newline at end of file
